# LAN Access Sample for PowerSupply            Ver1.00
# 対象機種は単出力電源PSW/PSU/PFR/PPXシリーズです。
# 本サンプルはWindowsでのみ動作確認となります。
# 標準のsocketモジュールを使用します。
# GUI表示はTkinterを使用しています。
# 測定に必要な時間をインターバルに指定してください。

# coding:utf-8
import socket           # socketモジュール
import tkinter as tk    # tkモジュール
import tkinter.scrolledtext
import time

from time import sleep
from tkinter import ttk

instr = socket.socket(socket.AF_INET, socket.SOCK_STREAM) 
ipAddr = "192.168.1.100"      # IPv4アドレス指定
ports = 2268                  # Socketポート指定

loopFlg = 0

def Open_clicked():
    global instr
    global ipAddr
    global ports

    btn1['state'] = tk.DISABLED
    btn2['state'] = tk.NORMAL
    btn3['state'] = tk.DISABLED
    btn4['state'] = tk.NORMAL
    btn5['state'] = tk.DISABLED
    btn6['state'] = tk.NORMAL
    btn7['state'] = tk.NORMAL
    btn8['state'] = tk.NORMAL
    btn9['state'] = tk.NORMAL
    txtRecive.delete('1.0',tk.END)

    ipAddr = txtIpaddr.get()
    ports  = int(txtPort.get())
    try:
        instr.connect((ipAddr, ports)) 

        instr.send("*idn?\n".encode("utf-8")) 
        sleep(0.1)
        txtRcv = instr.recv(256) 

        txtRecive.insert(tk.END,txtRcv.decode('ascii'))

    except:
        txtRecive.insert(tk.END,'Device Error')

def Close_clicked():
    global instr

    instr.send(":OUTP 0\n".encode("utf-8"))
    instr.send(":syst:comm:rlst loc\n".encode("utf-8"))
    btn1['state'] = tk.NORMAL
    btn2['state'] = tk.DISABLED
    btn3['state'] = tk.NORMAL
    btn4['state'] = tk.DISABLED
    btn5['state'] = tk.DISABLED
    btn6['state'] = tk.DISABLED
    btn7['state'] = tk.DISABLED
    btn8['state'] = tk.DISABLED
    btn9['state'] = tk.DISABLED
    instr.close()


def interval_work():                            # インターバルで行う処理を記述
    global loopFlg
    global instr
    
    instr.send(":MEAS:VOLT?;:MEAS:CURR?\n".encode("utf-8"))
    sleep(0.1)
    txtRcv = instr.recv(256) 
    txtRecive.insert(tk.END,time.ctime() + '   ,' + txtRcv.decode('ascii').replace('\r','')  )
    txtRecive.see('end')
    if (loopFlg == 1):
        root.after(1000, interval_work)              # インターバルの時間(ms)を指定


def Exit_clicked():

    root.destroy()

def Loop_clicked():
    global loopFlg
    loopFlg = 1 
    btn2['state'] = tk.DISABLED
    btn4['state'] = tk.DISABLED
    btn5['state'] = tk.NORMAL
    txtRecive.delete('1.0',tk.END)

    interval_work()

def Stop_clicked():
    global loopFlg
    loopFlg = 0
    btn2['state'] = tk.NORMAL
    btn4['state'] = tk.NORMAL
    btn5['state'] = tk.DISABLED



def VOLT_clicked():
    global instr
    txtSend = ':VOLT '+ txtVolt.get() + '\n'
    instr.send(txtSend.encode("utf-8"))


def CURR_clicked():
    global instr
    txtSend = ':CURR '+ txtCurr.get() + '\n'
    instr.send(txtSend.encode("utf-8"))

def OON_clicked():
    global instr
    txtSend = ':OUTP 1\n'
    instr.send(txtSend.encode("utf-8"))

def OOF_clicked():
    global instr
    txtSend = ':OUTP 0\n'
    instr.send(txtSend.encode("utf-8"))

                                                 
root = tk.Tk()
root.geometry('430x320')
root.title('Socket Sample for PowerSupply')

label1 = tk.Label(root, text = 'IPv4 Addr:')
label1.grid(row=0, column=0,sticky = tk.E,pady=3)
txtIpaddr = ttk.Entry(root , width=16 )
txtIpaddr.delete(0,tk.END)
txtIpaddr.insert(tk.END,'192.168.1.100')
txtIpaddr.grid(row=0 , column=1,sticky = tk.W)

label2 = tk.Label(root, text = ' Port :' )
label2.grid(row=0, column=2,sticky = tk.E)
txtPort = ttk.Entry(root , width=7 )
txtPort.delete(0,tk.END)
txtPort.insert(tk.END,'2268')
txtPort.grid(row=0 , column=3,sticky = tk.W)

txtRecive = tkinter.scrolledtext.ScrolledText(root , width=52, height=13 )
txtRecive.grid(row=4 , column=0, columnspan = 4 ,padx=10,pady=10)

btn1 = tk.Button(master=root, text='Open' , command=Open_clicked ,width=10)
btn1.grid(row = 1 , column=0,pady=3 )
btn2 = tk.Button(master=root, text='Close' , command=Close_clicked , state =tk.DISABLED,width=10 )
btn2.grid(row = 1 , column=1)
btn3 = tk.Button(master=root, text='Exit' , command=Exit_clicked,width=8)
btn3.grid(row = 1 , column=3)
btn4 = tk.Button(master=root, text='LOOP'  , command=Loop_clicked, state =tk.DISABLED ,width=10)
btn4.grid(row = 3 , column=0,pady=3)
btn5 = tk.Button(master=root, text='STOP'  , command=Stop_clicked, state =tk.DISABLED ,width=10)
btn5.grid(row = 3 , column=1)
btn6 = tk.Button(master=root, text=':VOLT' , command=VOLT_clicked, state =tk.DISABLED ,width=8)
btn6.grid(row = 2 , column=0,pady=3)
btn7 = tk.Button(master=root, text=':CURR' , command=CURR_clicked, state =tk.DISABLED ,width=8)
btn7.grid(row = 2 , column=2)
btn8 = tk.Button(master=root, text='OUT ON'  , command=OON_clicked, state =tk.DISABLED ,width=8)
btn8.grid(row = 3 , column=2,pady=3)
btn9 = tk.Button(master=root, text='OUT OFF' , command=OOF_clicked, state =tk.DISABLED ,width=8)
btn9.grid(row = 3 , column=3)

txtVolt = ttk.Entry(root , width=8 )
txtVolt.delete(0,tk.END)
txtVolt.insert(tk.END,'3.0')
txtVolt.grid(row=2 , column=1)
txtCurr = ttk.Entry(root , width=8 )
txtCurr.delete(0,tk.END)
txtCurr.insert(tk.END,'1.0')
txtCurr.grid(row=2 , column=3)

root.mainloop()

